Learn R Programming

betareg (version 2.0-0)

GasolineYield: Estimation of Gasoline Yields from Crude Oil

Description

Operational data of the proportion of crude oil converted to gasoline after distilation and fractionation.

Usage

data("GasolineYield")

Arguments

source

Taken from Prater (1956).

Details

This dataset was collected by Prater (1956), its dependent variable is the proportion of crude oil after distilation and fractionation. This dataset was analyzed by Atkinson (1985), who used the linear regression model and noted that there is ``indication that the error distribution is not quite symmetrical, giving rise to some unduly large and small residuals'' (p. 60).

The dataset contains 32 observations on the response and on the independent variables. It has been noted (Daniel and Wood, 1971, Chapter 8) that there are only ten sets of values of the first three explanatory variables which correspond to ten different crudes and were subjected to experimentally controlled distilation conditions. These conditions are captured in variable batch and the data were ordered according to the ascending order of temp10.

References

Atkinson, A.C. (1985). Plots, Transformations and Regression: An Introduction to Graphical Methods of Diagnostic Regression Analysis. New York: Oxford University Press.

Daniel, C., and Wood, F.S. (1971). Fitting Equations to Data. New York: John Wiley and Sons.

Ferrari, S.L.P., and Cribari-Neto, F. (2004). Beta Regression for Modeling Rates and Proportions. Journal of Applied Statistics, 31(7), 799--815.

Prater, N.H. (1956). Estimate Gasoline Yields from Crudes. New York: Springer-Verlag.

See Also

betareg

Examples

Run this code
data("GasolineYield", package = "betareg")

gy1 <- betareg(yield ~ gravity + pressure + temp10 + temp, data = GasolineYield)
summary(gy1)

## Ferrari and Cribari-Neto (2004)
gy2 <- betareg(yield ~ batch + temp, data = GasolineYield)
## Table 1
summary(gy2)
## Figure 2
par(mfrow = c(3, 2))
plot(gy2, which = 1:4)
plot(gy2, which = 5, type = "deviance", sub.caption = "")
plot(gy2, which = 1, type = "deviance", sub.caption = "")

## exclude 4th observation
gy2a <- update(gy2, subset = -4)
gy2a
summary(gy2a)

Run the code above in your browser using DataLab