Learn R Programming

betareg (version 2.4-0)

ImpreciseTask: Imprecise Probabilities for Sunday Weather and Boeing Stock Task

Description

In this study participants were asked to estimate upper and lower probabilities for event to occur and not to occur.

Usage

data(ImpreciseTask)

Arguments

source

Taken from http://dl.dropbox.com/u/1857674/betareg/betareg.html.

Details

All participants in the study were either first- or second-year undergraduate students in psychology, none of whom had a strong background in probability or were familiar with imprecise probability theories.

For the sunday weather task see WeatherTask. For the Boeing stock task participants were asked to estimate the probability that Boeing's stock would rise more than those in a list of 30 companies.

For each task participants were asked to provide lower and upper estimates for the event to occur and not to occur.

References

Smithson, M., Merkle, E.C., and Verkuilen, J. (in press). Beta Regression Finite Mixture Models of Polarization and Priming. Journal of Educational and Behavioral Statistics.

Smithson, M., and Segale, C. (2009). Partition Priming in Judgments of Imprecise Probabilities. Journal of Statistical Theory and Practice, 3(1), 169--181.

Examples

Run this code
data("ImpreciseTask", package = "betareg")
wt_betamix <- betamix(location ~ difference * task, data = ImpreciseTask, k = 2,
  extra_components = extraComponent(type = "betareg", coef =
    list(mean = 0, precision = 8)),
  FLXconcomitant = FLXPmultinom(~ task))

Run the code above in your browser using DataLab