Compute the generalized leverages values for beta regression models.
Usage
gen.lev.betareg(x, ...)
Arguments
x
a fitted model using betareg.
...
further arguments passed to or from other methods.
Value
This function returns a vector containing the generalized leverage values.
The generalized leverage was proposed by Wei, Hu and Fung and was adapted to the beta regression model by Ferrari and Cribari-Neto (2004).
References
FERRARI, S.L.P., CRIBARI-NETO, F. (2004). Beta regression for modeling rates and proportions. Journal of Applied Statistics, v. 31, n. 7, p. 799-815.
WEI, B.-C., HU, Y.-Q. and FUNG, W.-K. (1998). Generalized leverage and its applications. Scandinavian Journal of Statistics, 25, 25-37