Learn R Programming

betareg (version 2.0-0)

gleverage: Generalized Leverage Values

Description

Compute the generalized leverages values for fitted models.

Usage

gleverage(model, ...)

Arguments

model
a model object.
...
further arguments passed to methods.

Value

  • gleverage is a new generic for computing generalized leverage values as suggested by Wei, Hu, and Fung (1998). Currently, there is only a method for betareg models, implementing the formulas from Ferrari and Cribari-Neto (2004). Currently, this requires computations and storage of order $n \times n$.

References

Ferrari, S.L.P., and Cribari-Neto, F. (2004). Beta Regression for Modeling Rates and Proportions. Journal of Applied Statistics, 31(7), 799--815.

Wei, B.-C., Hu, Y.-Q., and Fung, W.-K. (1998). Generalized Leverage and Its Applications. Scandinavian Journal of Statistics, 25, 25--37.

See Also

betareg

Examples

Run this code
data("GasolineYield", package = "betareg")
gy <- betareg(yield ~ batch + temp, data = GasolineYield)
gleverage(gy)

Run the code above in your browser using DataLab