Learn R Programming

betareg (version 2.0-0)

plot.betareg: Diagnostic Plots for betareg Objects

Description

Various types of standard diagnostic plots can be produced, involving various types of residuals, influence measures etc. Half-normal plots can be produced using a simulation approach.

Usage

## S3 method for class 'betareg':
plot(x, which = 1:4,
  caption = c("Residuals vs indices of obs.", "Cook's distance plot",
    "Generalized leverage vs predicted values", "Residuals vs linear predictor", 
    "Half-normal plot of residuals"),
    sub.caption = paste(deparse(x$call), collapse = ""), main = "", 
    ask = prod(par("mfcol")) < length(which) && dev.interactive(), 
    ..., type = "deviance", nsim = 100, level = 0.9)

x{fitted model object of class "betareg".} which{if a subset of the plots is required, specify a subset of the numbers 1:8.} caption{captions to appear above the plots.} sub.caption{common title-above figures if there are multiple.} main{title to each plot-in addition to the above caption.} ask{logical. If TRUE, the user is asked before each plot.} ...{other parameters to be passed through to plotting functions.} type{character indicating type of residual to be used, see residuals.betareg.} nsim{number of simulations in half-normal plots.} level{confidence level in half-normal plots.}

Ferrari, S.L.P., and Cribari-Neto, F. (2004). Beta Regression for Modeling Rates and Proportions. Journal of Applied Statistics, 31(7), 799--815.

betareg

data("GasolineYield", package = "betareg")

gy <- betareg(yield ~ gravity + pressure + temp10 + temp, data = GasolineYield)

par(mfrow = c(3, 2)) plot(gy, which = 1:5)

regression

Arguments