Learn R Programming

betareg (version 3.0-3)

predict.betareg: Prediction Method for betareg Objects

Description

Extract various types of predictions from beta regression models: either on the scale of responses in (0, 1) or the scale of the linear predictor.

Usage

## S3 method for class 'betareg':
predict(object, newdata = NULL,
  type = c("response", "link", "precision", "variance", "quantile"),
  na.action = na.pass, at = 0.5, ...)

Arguments

object
fitted model object of class "betareg".
newdata
optionally, a data frame in which to look for variables with which to predict. If omitted, the original observations are used.
type
character indicating type of predictions: fitted means of response ("response"), corresponding linear predictor ("link"), fitted precision parameter phi ("precision"), fitted variances of response ("var
na.action
function determining what should be done with missing values in newdata. The default is to predict NA.
at
numeric vector indicating the level(s) at which quantiles should be predicted (only if type = "quantile"), defaulting to the median at = 0.5.
...
currently not used.

Examples

Run this code
data("GasolineYield", package = "betareg")

gy2 <- betareg(yield ~ batch + temp | temp, data = GasolineYield)

cbind(
  predict(gy2, type = "response"),
  predict(gy2, type = "link"),
  predict(gy2, type = "precision"),
  predict(gy2, type = "variance"),
  predict(gy2, type = "quantile", at = c(0.25, 0.5, 0.75))
)

Run the code above in your browser using DataLab